#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor doc%{nil}
%if "%{flavor}" == "doc"
%define psuffix -doc
%bcond_without doc
%else
%define psuffix %{nil}
%bcond_with doc
%endif
Name:           python-atomicwrites%{psuffix}
Version:        1.4.1
Release:        1.6
Summary:        Atomic file writes for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/untitaker/python-atomicwrites
Source:         https://files.pythonhosted.org/packages/source/a/atomicwrites/atomicwrites-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with doc}
BuildRequires:  %{python_module atomicwrites}
BuildRequires:  %{python_module pytest}
BuildRequires:  python3-Sphinx
Provides:       %{python_module atomicwrites-doc = %{version}}
%endif
%python_subpackages

%description
Atomic file writes for python3.
Features that distinguish it from other similar libraries:

- Race-free assertion that the target file doesn't yet exist. This can be
  controlled with the 'overwrite' parameter.

- High-level API that wraps a very flexible class-based API.

%prep
%setup -q -n atomicwrites-%{version}
rm -rf atomicwrites.egg-info

%if %{with doc}
%package -n %{name}-doc
Summary:        Atomic file writes for Python (documentation)
Group:          Documentation/HTML

%description -n %{name}-doc
Atomic file writes for python3.
Features that distinguish it from other similar libraries:

- Race-free assertion that the target file doesn't yet exist. This can be
  controlled with the 'overwrite' parameter.

- High-level API that wraps a very flexible class-based API.

This package contains the documentation for both python2 and python3 versions
of python-atomicwrites
%endif

%build
%if %{without doc}
%python_build
%else
pushd docs
make html
rm _build/html/.buildinfo
popd
%endif

%install
%if %{without doc}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with doc}
%pytest
%endif

%if %{without doc}
%files %{python_files}
%defattr(-,root,root,-)
%doc README.rst
%license LICENSE
%{python_sitelib}/atomicwrites*

%else

%files -n %{name}-doc
%defattr(-,root,root,-)
%doc README.rst
%license LICENSE
%doc docs/_build/html
%endif

%changelog
* Mon Jul 25 2022 Dirk Müller <dmueller@suse.com>
- update to 1.4.1:
  * package is now unmaintained
  * python 3.8 support
  * README updates
  * Support ppc64le
* Fri Jan 28 2022 Matej Cepl <mcepl@suse.com>
- Rewrite into proper multibuild style.
* Tue May 12 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.4.0:
  * Update unsupported python versions
  * use fspath to ensure path is str or bytes
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Fri Mar  1 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.3.0
  * Restore ability to use tempfile kwargs other than dir
  * Avoid API breakage under Python 2
  * Passes kwargs through AtomicWriter to tempfile.NamedTemporaryFile
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Jul 18 2018 tchvatal@suse.com
- Versionify the provides to make old brp-checks happy
* Sun Jun 10 2018 jengelh@inai.de
- Drop other-OS mentions from description.
* Thu Jun  7 2018 toddrme2178@gmail.com
- Create separate -doc subpackage to build docs.
- Run tests in -doc subpackage to avoid dependency loop with
  python-pytest.
- Use license tag
* Fri Jun 30 2017 aloisio@gmx.com
- Converted to single-spec
* Wed Sep 21 2016 arun@gmx.de
- update to version 1.1.5:
  * Fix toxfile (#21)
  * Make atomic_write work on paths with no directory separator (#20)
  * Fix formatting
  * Skip stylecheck under py26
  * Add contributing.rst
  * Fix tox.ini
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sat Mar 26 2016 arun@gmx.de
- update to version 1.0.0:
  * Fix unintentional exception clobbering when rollback fails
  * Remove unused variable (fixes an unused variable warning)
  * Update copyright notice
  * Fix appveyor build
* Mon Feb 15 2016 arun@gmx.de
- update to version 0.1.9:
  * Fix UnboundLocalError
* Tue Jan 19 2016 sleep_walker@opensuse.org
- clean the spec file (not only) with spec-cleaner
- fix %%check part
* Mon Jan 18 2016 sleep_walker@opensuse.org
- let there be python3-atomicwrites
